import org.easymock.MockControl; 

public class CustomerTest extends junit.framework.TestCase {
	private Customer customer;

	private Movie buffalo66, jungleBook, pulpFiction;

	private MockControl control; 
	private IPrinter mockPrinter;

	protected void setUp() {
		customer = new Customer();
		buffalo66 = new Movie("Buffalo 66", new StubPrice());
		jungleBook = new Movie("Das Dschungelbuch", Price.REGULAR);
		pulpFiction = new Movie("Pulp Fiction", Price.NEWRELEASE);

		control = MockControl.createStrictControl(IPrinter.class); 
		mockPrinter = (IPrinter) control.getMock(); 
	}

	public void testRentingNoMovie() {
		assertEquals(new Euro(0.00), customer.getTotalCharge());
	}

	public void testPrintingStatementFooterWithOneMovie() {
		customer.rentMovie(pulpFiction, 1);
		String actual = customer.printStatementFooter();
		String expected = "Gesamt: 2,00\n";
		assertEquals(expected, actual);
	}

	public void testRentingThreeMovies() {
		customer.rentMovie(pulpFiction, 2);
		customer.rentMovie(pulpFiction, 3);
		customer.rentMovie(pulpFiction, 4);
		assertEquals(new Euro(11.25), customer.getTotalCharge());
	}

	public void testStatementDetailForRentalDetails() {
		customer.rentMovie(buffalo66, 1);
		String statement = customer.printStatementDetail();
		assertEquals("\tBuffalo 66\t2,00\n", statement);
	}

	public void testStatementDetailForRentalLines() throws Exception {
		mockPrinter.tab(); 
		mockPrinter.print("Buffalo 66"); 
		mockPrinter.tab(); 
		mockPrinter.print("2,00"); 
		mockPrinter.crlf(); 
		mockPrinter.tab(); 
		mockPrinter.print("Das Dschungelbuch"); 
		mockPrinter.tab(); 
		mockPrinter.print("1,50"); 
		mockPrinter.crlf(); 
		mockPrinter.cutPaper();
		
		control.replay(); 

		customer.rentMovie(buffalo66, 4);
		customer.rentMovie(jungleBook, 1);
		customer.printStatementDetail(mockPrinter);
		
		control.verify(); 
	}
}