import junit.framework.TestCase;

public class EuroTest extends TestCase {
	private Euro two;

	protected void setUp() {
		two = new Euro(2.00);
	}

	public void testAmount() {
		assertTrue(2.00 == two.getAmount());
	}

	public void testRounding() {
		Euro rounded = new Euro(1.995);
		assertEquals("amount not rounded", two, rounded);
		
		assertEquals(new Euro(0.49), new Euro(0.494)); 
		assertEquals(new Euro(0.50), new Euro(0.495)); 
	}

	public void testAdding() {
		Euro sum = two.plus(two);
		assertEquals("sum", new Euro(4.00), sum);
		assertEquals("two", new Euro(2.00), two);
	}

	public void testMultiplying() {
		Euro result = two.times(7);
		assertEquals(new Euro(14.00), result);
		assertEquals(new Euro(2.00), two);
	}

	public void testFormatting() {
		assertEquals("2,00", two.format());
	}

	public void testEquality() {
		assertEquals(two, two);
		assertEquals(two, new Euro(2.00));
		assertEquals(new Euro(2.00), two);
		assertFalse(two.equals(new Euro(7.00)));
		assertFalse(two.equals(null));
		assertFalse(two.equals(new Object()));
	}

	public void testNegativeAmount() {
		try {
			final double NEGATIVE_AMOUNT = -2.00;
			new Euro(NEGATIVE_AMOUNT);
			fail("amount must not be negative");
		} catch (IllegalArgumentException expected) {
		}
		
		try { 
			two.times(-1); 
			fail("multiplying with a negative number not allowed"); 
			} catch (IllegalArgumentException expected) {
			} 
	}
}